# oneNeuron_pypi
oneNeuron_pypi

# Refrence -
[official python docs(http://packaging.python.org/tutorials/packaging-projects/)]

[github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)